vers 12

set more off

capture log close

log using stakeholder.log, replace  

use stakeholder.dta, clear

preserve

*     ***************************************************************** *;
*     ***************************************************************** *;
*     File-Name:  stakeholder.do	    		                        *;
*     Date:       December 12, 2014                                     *;
*     Authors:    Agn, Dellmuth, and Tallberg                          *;
*     Purpose:    Replicate results for stakeholder paper in ROIO		*;
*     Input File: stakeholder.dta                                       *;
*     Output File:stakeholder.log    		                            *;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*     Online Appendix, Tables B1 and B2									*;
*     ****************************************************************  *;

*logout, save(TableB1) word replace: ///
tabstat rep del acc opp type staff infl ///
sal form dec impl mon p_demo, stats(min mean max sd n) columns(statistics)

*logout, save(TableB2) word replace: ///
corr rep del acc opp type staff infl ///
sal form dec impl mon p_demo


*     ****************************************************************  *;
*     Paper, Table 1 													*;
*     ****************************************************************  *;

*logout, save(Table1-row1) excel word replace: ///
tab rep io 

*logout, save(Table1-row2) excel word replace: ///
tab del io 

*logout, save(Table1-row3) excel word replace: ///
tab acc io 


*     ****************************************************************  *;
*     Paper, Table 2 													*;
*     ****************************************************************  *;

*logout, save(Table2-row1) excel word replace: ///
tab rep opp 

*logout, save(Table2-row2) excel word replace: ///
tab del opp 

*logout, save(Table2-row3) excel word replace: ///
tab acc opp 


*     ****************************************************************  *;
*     Paper, Table 3 													*;
*     ****************************************************************  *;

*Regression results

reg rep opp type staff infl sal 
eststo model1

reg rep opp type staff infl sal ///
form dec impl mon p_demo
eststo model2

reg del opp type staff infl sal
eststo model3

reg del opp type staff infl sal ///
form dec impl mon p_demo
eststo model4

reg acc opp type staff infl sal 
eststo model5

reg acc opp type staff infl sal ///
form dec impl mon p_demo 
eststo model6

esttab model1 model2 model3 model4 model5 model6 using table3.rtf, ///
starlevels(* .10 ** .05 *** .01) b(%9.2f) ar2(4) se(%9.2f) scalars(N) replace

*Substantive interpretation of regression results


quietly estsimp reg rep opp type staff infl sal form dec impl mon p_demo
eststo model2simulated
setx mean
simqi, fd(ev) changex(staff 1 7) 
simqi, fd(ev) changex(sal 0 3)  
simqi, fd(ev) changex(p_demo 0 10) 
drop b1-b11 b12

quietly estsimp reg del opp type staff infl sal form dec impl mon p_demo
eststo model4simulated
setx mean
simqi, fd(ev) changex(infl 1 10) 
simqi, fd(ev) changex(sal 0 3)
drop b1-b11 b12

quietly estsimp reg acc opp type staff infl sal form dec impl mon p_demo
eststo model6simulated
setx mean
simqi, fd(ev) changex(staff 1 7) 
simqi, fd(ev) changex(sal 0 3) 
simqi, fd(ev) changex(p_demo 0 10) 
drop b1-b11 b12


*     ****************************************************************  *;
*     Paper, test of regression assumptions								*;
*     ****************************************************************  *;


*Test of homoscedasticity assumption

quietly reg rep opp type staff infl sal 
estat hettest 

quietly reg rep opp type staff infl sal ///
form dec impl mon p_demo
estat hettest 

quietly reg del opp type staff infl sal
estat hettest 

quietly reg del opp type staff infl sal ///
form dec impl mon p_demo
estat hettest 

quietly reg acc opp type staff infl sal 
estat hettest 

quietly reg acc opp type staff infl sal ///
form dec impl mon p_demo 
estat hettest 

*Test of normality assumption

quietly reg rep opp type staff infl sal 
predict resid, resid
kdensity resid, normal saving(model1-res.gph, replace)
drop resid

quietly reg rep opp type staff infl sal ///
form dec impl mon p_demo
predict resid, resid
kdensity resid, normal saving(model2-res.gph, replace)
drop resid

quietly reg del opp type staff infl sal
predict resid, resid
kdensity resid, normal saving(model3-res.gph, replace)
drop resid

quietly reg del opp type staff infl sal ///
form dec impl mon p_demo
predict resid, resid 
kdensity resid, normal saving(model4-res.gph, replace)
drop resid

quietly reg acc opp type staff infl sal 
predict resid, resid 
kdensity resid, normal saving(model5-res.gph, replace)
drop resid

quietly reg acc opp type staff infl sal ///
form dec impl mon p_demo 
predict resid, resid 
kdensity resid, normal saving(model6-res.gph, replace)
drop resid

*Test for multi-collinearity using collin.pkg from http://www.ats.ucla.edu/stat/stata/ado/analysis/

collin acc opp type staff infl sal ///
form dec impl mon p_demo


*     ****************************************************************  *;
*     Paper, robustness checks											*;
*     ****************************************************************  *;

*Entering variables separately

reg rep opp type   
eststo model1a

reg rep opp staff   
eststo model1b

reg rep opp infl  
eststo model1c

reg rep opp sal 
eststo model1d

reg rep opp type staff infl sal   ///
form 
eststo model2a

reg rep opp type staff infl sal  ///
dec 
eststo model2b

reg rep opp type staff infl sal  ///
impl 
eststo model2c

reg rep opp type staff infl sal ///
mon 
eststo model2d

reg rep opp type staff infl sal ///
p_demo
eststo model2e

esttab model1a model1b model1c model1d model2a model2b model2c ///
model2d model2e using robust-models1-and-2.rtf, ///
starlevels(* .10 ** .05 *** .01) b(%9.2f) ar2(4) se(%9.2f) scalars(N) replace


reg del opp type   
eststo model3a

reg del opp staff   
eststo model3b

reg del opp infl  
eststo model3c

reg del opp sal 
eststo model3d

reg del opp type staff infl sal   ///
form 
eststo model4a

reg del opp type staff infl sal  ///
dec 
eststo model4b

reg del opp type staff infl sal  ///
impl 
eststo model4c

reg del opp type staff infl sal ///
mon 
eststo model4d

reg del opp type staff infl sal ///
p_demo
eststo model4e

esttab model3a model3b model3c model3d model4a model4b model4c ///
model4d model4e using robust-models3-and-4.rtf, ///
starlevels(* .10 ** .05 *** .01) b(%9.2f) ar2(4) se(%9.2f) scalars(N) replace



reg acc opp type   
eststo model5a

reg acc opp staff   
eststo model5b

reg acc opp infl  
eststo model5c

reg acc opp sal 
eststo model5d

reg acc opp type staff infl sal   ///
form 
eststo model6a

reg acc opp type staff infl sal  ///
dec 
eststo model6b

reg acc opp type staff infl sal  ///
impl 
eststo model6c

reg acc opp type staff infl sal ///
mon 
eststo model6d

reg acc opp type staff infl sal ///
p_demo
eststo model6e

esttab model5a model5b model5c model5d model6a model6b model6c ///
model6d model6e using robust-models5-and-6.rtf, ///
starlevels(* .10 ** .05 *** .01) b(%9.2f) ar2(4) se(%9.2f) scalars(N) replace


*Adding IO fixed effects

reg rep opp type staff infl sal i.io
eststo model1

reg rep opp type staff infl sal ///
form dec impl mon p_demo i.io
eststo model2

reg del opp type staff infl sal i.io
eststo model3

reg del opp type staff infl sal ///
form dec impl mon p_demo i.io
eststo model4

reg acc opp type staff infl sal i.io
eststo model5

reg acc opp type staff infl sal ///
form dec impl mon p_demo i.io
eststo model6

esttab model1 model2 model3 model4 model5 model6 using robust-table3-io-fixed-effects.rtf, ///
starlevels(* .10 ** .05 *** .01) b(%9.2f) ar2(4) se(%9.2f) scalars(N) replace


*Using robust standard errors clustered at the level of IOs


reg rep opp type staff infl sal, cluster(io)
eststo model1

reg rep opp type staff infl sal ///
form dec impl mon p_demo, cluster(io)
eststo model2

reg del opp type staff infl sal, cluster(io)
eststo model3

reg del opp type staff infl sal ///
form dec impl mon p_demo, cluster(io)
eststo model4

reg acc opp type staff infl sal, cluster(io)
eststo model5

reg acc opp type staff infl sal ///
form dec impl mon p_demo, cluster(io)
eststo model6

esttab model1 model2 model3 model4 model5 model6 using robust-table3-io-clustered-se.rtf, ///
starlevels(* .10 ** .05 *** .01) b(%9.2f) ar2(4) se(%9.2f) scalars(N) replace


*Using weighted data

gen id=_n
svyset id [pweight = dweight] 

svy: reg rep opp type staff infl sal
eststo model1w

svy: reg rep opp type staff infl sal ///
form dec impl mon p_demo
eststo model2w

svy: reg del opp type staff infl sal
eststo model3w

svy: reg del opp type staff infl sal ///
form dec impl mon p_demo
eststo model4w

svy: reg acc opp type staff infl sal
eststo model5w

svy: reg acc opp type staff infl sal ///
form dec impl mon p_demo
eststo model6w

esttab model1w model2w model3w model4w model5w model6w using robust-table3-weighted-data.rtf, ///
starlevels(* .10 ** .05 *** .01) b(%9.2f) ar2(4) se(%9.2f) scalars(N) replace

drop id

*Using ordered logit


ologit rep opp type staff infl sal
eststo model1l

ologit rep opp type staff infl sal ///
form dec impl mon p_demo
eststo model2l

ologit del opp type staff infl sal
eststo model3l

ologit del opp type staff infl sal ///
form dec impl mon p_demo
eststo model4l

ologit acc opp type staff infl sal
eststo model5l

ologit acc opp type staff infl sal ///
form dec impl mon p_demo
eststo model6l

esttab model1l model2l model3l model4l model5l model6l using robust-table3-ologit.rtf, ///
starlevels(* .10 ** .05 *** .01) b(%9.2f) ar2(4) se(%9.2f) scalars(N) replace


capture log close

